summaryrefslogtreecommitdiff
path: root/compiler/GHC/CoreToIface.hs
diff options
context:
space:
mode:
authorSylvain Henry <sylvain@haskus.fr>2020-03-02 11:43:03 +0100
committerMarge Bot <ben+marge-bot@smart-cactus.org>2020-03-16 23:53:24 -0400
commit18a346a4b5a02b8c62e8eedb91b35c2d8e754b96 (patch)
tree59121ffd5a46c1987a184db3842a3089f6250d11 /compiler/GHC/CoreToIface.hs
parent818b3c38e7548f4720815f76969238d82c9650f7 (diff)
downloadhaskell-18a346a4b5a02b8c62e8eedb91b35c2d8e754b96.tar.gz
Modules: Core (#13009)
Update submodule: haddock
Diffstat (limited to 'compiler/GHC/CoreToIface.hs')
-rw-r--r--compiler/GHC/CoreToIface.hs18
1 files changed, 9 insertions, 9 deletions
diff --git a/compiler/GHC/CoreToIface.hs b/compiler/GHC/CoreToIface.hs
index 3aad60b025..ee24c60bee 100644
--- a/compiler/GHC/CoreToIface.hs
+++ b/compiler/GHC/CoreToIface.hs
@@ -48,28 +48,28 @@ module GHC.CoreToIface
import GhcPrelude
import GHC.Iface.Syntax
-import DataCon
+import GHC.Core.DataCon
import Id
import IdInfo
import GHC.Core
-import TyCon hiding ( pprPromotionQuote )
-import CoAxiom
+import GHC.Core.TyCon hiding ( pprPromotionQuote )
+import GHC.Core.Coercion.Axiom
import TysPrim ( eqPrimTyCon, eqReprPrimTyCon )
import TysWiredIn ( heqTyCon )
import MkId ( noinlineIdName )
import PrelNames
import Name
import BasicTypes
-import Type
-import PatSyn
+import GHC.Core.Type
+import GHC.Core.PatSyn
import Outputable
import FastString
import Util
import Var
import VarEnv
import VarSet
-import TyCoRep
-import TyCoTidy ( tidyCo )
+import GHC.Core.TyCo.Rep
+import GHC.Core.TyCo.Tidy ( tidyCo )
import Demand ( isTopSig )
import Cpr ( topCprSig )
@@ -345,12 +345,12 @@ toIfaceAppArgsX fr kind ty_args
VisArg -> Required
InvisArg -> Inferred
-- It's rare for a kind to have a constraint argument, but
- -- it can happen. See Note [AnonTCB InvisArg] in TyCon.
+ -- it can happen. See Note [AnonTCB InvisArg] in GHC.Core.TyCon.
go env ty ts@(t1:ts1)
| not (isEmptyTCvSubst env)
= go (zapTCvSubst env) (substTy env ty) ts
- -- See Note [Care with kind instantiation] in Type.hs
+ -- See Note [Care with kind instantiation] in GHC.Core.Type
| otherwise
= -- There's a kind error in the type we are trying to print